@@ -26,6 +26,7 @@ impl VmStack {
     }
 }
 
+#[cfg(any(target_os = "linux", target_os = "android"))]
 impl Column for VmStack {
     fn add(&mut self, proc: &ProcessInfo) {
         let (raw_content, fmt_content) = if let Some(ref curr_status) = proc.curr_status {
@@ -45,3 +46,17 @@ impl Column for VmStack {
 
     column_default!(u64);
 }
+
+#[cfg_attr(tarpaulin, skip)]
+#[cfg(target_os = "freebsd")]
+impl Column for VmStack {
+    fn add(&mut self, proc: &ProcessInfo) {
+        let raw_content = (proc.curr_proc.info.ssize as u64).saturating_mul(4096);
+        let fmt_content = bytify(raw_content);
+
+        self.fmt_contents.insert(proc.pid, fmt_content);
+        self.raw_contents.insert(proc.pid, raw_content);
+    }
+
+    column_default!(u64);
+}
